@@ -1,8 +1,8 @@
-package Dist::Zilla::Plugin::DualLife; # git description: v0.05-8-g1ba4908
+package Dist::Zilla::Plugin::DualLife; # git description: v0.06-3-gb9840ff
 # ABSTRACT: Distribute dual-life modules with Dist::Zilla
 # KEYWORDS: Makefile.PL core dual-life install INSTALLDIRS
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moose;
 use List::Util qw(first min);
@@ -108,6 +108,8 @@ sub munge_files
                 $self->log_debug([ 'looking up %s in Module::CoreList...', $_->name ]);
                 my $mmd = $self->module_metadata_for_file($_);
                 my $module = ($mmd->packages_inside)[0];
+                # this returns the empty list when the module is not in core,
+                # so we don't have to worry about passing undefs to min().
                 Module::CoreList->first_release($module);
             } @{ $self->module_files }
         );
@@ -158,7 +160,7 @@ Dist::Zilla::Plugin::DualLife - Distribute dual-life modules with Dist::Zilla
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
